@@ -1,15 +1,24 @@
 #!/bin/sh
 echo 'name: redis
-version: 0.12.1
-id: redis-0.12.1-33fe4659046a1b4961e438bac26f9a82
+version: 0.13
+id: redis-0.13-b0aa2b39bd751251a62cdbaa8f1b01dc
 
 license: MIT
 copyright: Copyright (c) 2009-2010 Alexander Bogdanov
 maintainer: Alexander Bogdanov <andorn@gmail.com>
-stability: beta
+stability: deprecated
 homepage:
 package-url:
-description: Redis (<http://redis.io>) is an open source, BSD licensed, advanced
+synopsis: A driver for Redis key-value database
+description: Caution! This library is currently not supported. If you looking
+             for an alternative, hedis package is a great one. It looks more
+             complete and more "functional" in its nature. If you absolutely
+             need *this* library, please let me know, I'\''ll do my best to help
+             you in any way. On the other hand, if you want to adopt this
+             library, do not hesitate and let me know too. Many thanks!
+             .
+             .
+             Redis (<http://redis.io>) is an open source, BSD licensed, advanced
              key-value store. It is often referred as a data structure server
              since keys can contain different data structures, such as strings,
              hashes, lists, sets and sorted sets.
@@ -30,23 +39,9 @@ description: Redis (<http://redis.io>) is an open source, BSD licensed, advanced
              .
              Please let me know if tests or benchmark goes terribly wrong.
              .
-             Changes from v0.11:
+             Changes from v0.12:
              .
-             - Drop parsec dependency
-             .
-             - New commands implemented: incrbyfloat and hincrbyfloat
-             .
-             - Added variadic versions of del, hdel, lpush, rpush, sadd, srem,
-             zadd, zrem (named as del_, hdel_ etc.)
-             .
-             - Fixed compilation with GHC 7.2 (and hopefully with more recent
-             versions too), thanks Ben Gamari and Sean Hess for reporting.
-             .
-             - Using RLock from concurrent-extra fixes multithreading issues,
-             thanks Dmitry Dzhus for reporting
-             .
-             - Hopefully, fix building on Windows (untested), thanks Piotr
-             Staszewski and Alexander Dorofeev
+             - nothing here
 category: Database
 author: Alexander Bogdanov <andorn@gmail.com>
 pkgpath: databases/hs-redis
@@ -55,27 +50,28 @@ exposed-modules: Database.Redis.Redis Database.Redis.Monad
                  Database.Redis.ByteStringClass Database.Redis.Monad.State
                  Database.Redis.Utils.Lock Database.Redis.Utils.Monad.Lock
 hidden-modules: Database.Redis.Internal Database.Redis.Info
-import-dirs: /usr/local/lib/ghc/redis-0.12.1
-library-dirs: /usr/local/lib/ghc/redis-0.12.1
-hs-libraries: HSredis-0.12.1
+trusted: False
+import-dirs: /usr/local/lib/ghc/redis-0.13
+library-dirs: /usr/local/lib/ghc/redis-0.13
+hs-libraries: HSredis-0.13
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: MonadCatchIO-mtl-0.3.0.4-d2dba4754f14d16f9561e6570f2b735d
-         base-4.3.1.0-4365831fa9af03083be195ed161cbbc1
-         bytestring-0.9.1.10-d11caeadd9605139e1a59850ce083826
-         concurrent-extra-0.7.0.4-e66c862b731e5514e904e97f808da3a0
-         containers-0.4.0.0-b4885363abca642443ccd842502a3b7e
-         mtl-2.0.1.0-5b7a9cce5565d8cc8721ba4f95becf1b
-         network-2.3.0.5-435de5913c7c66da653cc03396522a6b
-         old-time-1.0.0.6-088ba18f14be11f5303a5ce07fd2f643
-         utf8-string-0.3.6-213e09c7f4f705610e4e35b79f03acb5
+depends: MonadCatchIO-mtl-0.3.0.5-50eb20252600070062edde5090a7ae72
+         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
+         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
+         concurrent-extra-0.7.0.4-d9b28f47065ab7f1ec28b99052c962a5
+         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
+         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
+         network-2.3.1.0-abef231ef624b7502aa8b0353f2d5ca3
+         old-time-1.1.0.0-c11d19d5710541e7a9ae41c1582972eb
+         utf8-string-0.3.8-2777416918ab74e3e486858d8ef2fdf6
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-redis-0.12.1/html/redis.haddock
-haddock-html: /usr/local/share/doc/hs-redis-0.12.1/html
+haddock-interfaces: /usr/local/share/doc/hs-redis-0.13/html/redis.haddock
+haddock-html: /usr/local/share/doc/hs-redis-0.13/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
